if importPath==nil then importPath=string.gsub(getfenv(1)._.Name,"%.DefaultAnnotationWindow","").."." end
if resourcePath==nil then resourcePath=string.gsub(importPath,"%.","/").."Resources/" end
string.UTFEncode=function(str)
	local ret = "";
	for i,v in ipairs({str:byte(1,-1)}) do
		if (v < 32) or (v > 125) then
			ret = ret .. "\\"..string.sub(string.format("00%d",v),-3);
		else
			ret = ret .. string.char(v);
		end
	end
	return ret;
end
--[[
 	This dialog is designed to be used by the plugin author only.  If you use this dialog to creat annotations, they will be overwritten by
	any default annotations that are included in the next update.

	This dialog allows rapid creation of default annotations by selecting the map, annotation type and custom value then when the user clicks
	the "Add" button, the text to create an annotation at the user's coordinates with the text of the users's target will be added to the 
	textboxes on the Annotations and Resources tabs.

	The lock on the Type list only affects the query button.  If the type is locked, the query will fill all available fields but will not try
	to resolve the type. This is handy when processing a lot of undetectable types like NPCs.

]]--
defAnnWindow=Turbine.UI.Lotro.Window();
defAnnWindow:SetText("Default Annotations Maker");
defAnnWindow:SetVisible(false);
defAnnWindow:SetSize(550,600);
local defTop,defLeft
if Settings.DefAnnotWindowTopPercent==nil then
	defTop=(displayHeight-defAnnWindow:GetHeight())/2
else
	defTop=Settings.DefAnnotWindowTopPercent*displayHeight
end
if Settings.DefAnnotWindowLeftPercent==nil then
	defLeft=(displayWidth-defAnnWindow:GetWidth())/2
else
	defLeft=Settings.DefAnnotWindowLeftPercent*displayWidth
end

defAnnWindow:SetPosition(defLeft,defTop);

defAnnWindow.SettingsTab=Turbine.UI.Control();
defAnnWindow.SettingsTab:SetParent(defAnnWindow);
defAnnWindow.SettingsTab:SetPosition(10,40);
defAnnWindow.SettingsTab:SetSize(defAnnWindow:GetWidth()-20,defAnnWindow:GetHeight()-80);
defAnnWindow.SettingsTab:SetBackColor(Turbine.UI.Color(0,0,0));

defAnnWindow.StringIndexCaption=Turbine.UI.Label();
defAnnWindow.StringIndexCaption:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.StringIndexCaption:SetPosition(0,0);
defAnnWindow.StringIndexCaption:SetSize(90,20);
defAnnWindow.StringIndexCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
defAnnWindow.StringIndexCaption:SetForeColor(Settings.fontColor);
defAnnWindow.StringIndexCaption:SetText("Index:");
defAnnWindow.StringIndexCaption:SetMouseVisible(false);
defAnnWindow.StringIndexText=Turbine.UI.Lotro.TextBox();
defAnnWindow.StringIndexText:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.StringIndexText:SetSize(80,20);
defAnnWindow.StringIndexText:SetPosition(90,defAnnWindow.StringIndexCaption:GetTop());
defAnnWindow.StringIndexText:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
defAnnWindow.StringIndexText:SetText(tostring(NumDefaultStrings+1)); -- default it to the number of strings on the currently displayed map plus 1

defAnnWindow.MapCaption=Turbine.UI.Label();
defAnnWindow.MapCaption:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.MapCaption:SetPosition(0,defAnnWindow.StringIndexCaption:GetTop()+25);
defAnnWindow.MapCaption:SetSize(90,20);
defAnnWindow.MapCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
defAnnWindow.MapCaption:SetForeColor(Settings.fontColor);
defAnnWindow.MapCaption:SetText("Map:");
defAnnWindow.MapCaption:SetMouseVisible(false);
defAnnWindow.MapSelect=DropDownList()
defAnnWindow.MapSelect:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.MapSelect:SetSize(300,20);
defAnnWindow.MapSelect:SetPosition(90,defAnnWindow.MapCaption:GetTop());
defAnnWindow.MapSelect:SetBorderColor(Settings.trimColor);
defAnnWindow.MapSelect:SetBackColor(Settings.backColor);
defAnnWindow.MapSelect.CurrentValue:SetBackColor(Settings.backColor);
defAnnWindow.MapSelect:SetTextColor(Settings.listTextColor);
defAnnWindow.MapSelect:SetDropRows(15);

defAnnWindow.MapID=Turbine.UI.Label();
defAnnWindow.MapID:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.MapID:SetPosition(defAnnWindow.MapSelect:GetLeft()+defAnnWindow.MapSelect:GetWidth()+5,defAnnWindow.MapSelect:GetTop())
defAnnWindow.MapID:SetSize(defAnnWindow.SettingsTab:GetWidth()-defAnnWindow.MapID:GetLeft()-5,20)
defAnnWindow.MapID:SetFont(Turbine.UI.Lotro.Font.Verdana18)
defAnnWindow.MapID:SetText("0");

for tmpIndex=1,#mapInfo do
	defAnnWindow.MapSelect:AddItem(Resource[1][mapInfo[tmpIndex][2]],tmpIndex)
end

defAnnWindow.MapSelect:SetSelectedIndex(mapWindow.CurrentMapID);
defAnnWindow.MapID:SetText(tostring(mapWindow.CurrentMapID));
defAnnWindow.MapSelect.SelectedIndexChanged=function()
	defAnnWindow.MapID:SetText(tostring(defAnnWindow.MapSelect:GetValue()));
end

defAnnWindow.TypeCaption=Turbine.UI.Label();
defAnnWindow.TypeCaption:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.TypeCaption:SetPosition(0,defAnnWindow.MapCaption:GetTop()+25);
defAnnWindow.TypeCaption:SetSize(90,18);
defAnnWindow.TypeCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
defAnnWindow.TypeCaption:SetForeColor(Settings.fontColor);
defAnnWindow.TypeCaption:SetText("Type:");
defAnnWindow.TypeCaption:SetMouseVisible(false);

defAnnWindow.TypeList=DropDownList();
defAnnWindow.TypeList.ValueMask:SetVisible(false) -- allow typing in the entry field
defAnnWindow.TypeList:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.TypeList:SetPosition(90,defAnnWindow.TypeCaption:GetTop());
defAnnWindow.TypeList:SetSize(300,20);
defAnnWindow.TypeList:SetBorderColor(Settings.trimColor);
defAnnWindow.TypeList:SetBackColor(Settings.backColor);
defAnnWindow.TypeList:SetCurrentBackColor(Settings.backColor);
defAnnWindow.TypeList:SetTextColor(Settings.listTextColor);
defAnnWindow.TypeList:SetDropRows(5);

defAnnWindow.TypeList:SetMatchType(2)

do
	local tmpTypeTbl={}
	local tmpIndex=1
	for tmpIndex,v in ipairs(iconInfo) do
		if tmpIndex>13 or tmpIndex==5 or tmpIndex==11 then
			table.insert(tmpTypeTbl,{Resource[1][v[1]],tmpIndex})
		end
	end
	table.sort(tmpTypeTbl,function(a,b)if (a[1]<b[1]) then return true end end)
	for k,v in ipairs(tmpTypeTbl) do
		if v[2]==5 then tmpIndex=k end
		defAnnWindow.TypeList:AddItem(v[1],v[2]);
	end
	defAnnWindow.TypeList:SetSelectedIndex(tmpIndex); -- default it to POI
end
defAnnWindow.TypeList.SelectedIndexChanged=function()
end

defAnnWindow.TypeList:SetZOrder(80);
defAnnWindow.MapSelect:SetZOrder(85);

defAnnWindow.TypeLock=Turbine.UI.Control();
defAnnWindow.TypeLock:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.TypeLock:SetPosition(defAnnWindow.TypeList:GetLeft()+defAnnWindow.TypeList:GetWidth()+5,defAnnWindow.TypeList:GetTop());
defAnnWindow.TypeLock:SetSize(20,20);
defAnnWindow.TypeLock:SetBlendMode(Turbine.UI.BlendMode.Overlay);
defAnnWindow.TypeLock:SetBackground(0x410001d0); --0x410001d0= locked
defAnnWindow.TypeLock.Locked=true;
defAnnWindow.TypeLock.MouseClick=function()
	defAnnWindow.TypeLock.Locked=not defAnnWindow.TypeLock.Locked;
	if defAnnWindow.TypeLock.Locked then
		defAnnWindow.TypeLock:SetBackground(0x410001d0);
	else
		defAnnWindow.TypeLock:SetBackground(0x410001cf);
	end
end

defAnnWindow.NameCaption=Turbine.UI.Label();
defAnnWindow.NameCaption:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.NameCaption:SetPosition(0,defAnnWindow.TypeCaption:GetTop()+25);
defAnnWindow.NameCaption:SetSize(90,18);
defAnnWindow.NameCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
defAnnWindow.NameCaption:SetForeColor(Settings.fontColor);
defAnnWindow.NameCaption:SetText("Name:");
defAnnWindow.NameCaption:SetMouseVisible(false);
defAnnWindow.NameText=Turbine.UI.Lotro.TextBox();
defAnnWindow.NameText:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.NameText:SetPosition(90,defAnnWindow.NameCaption:GetTop());
defAnnWindow.NameText:SetSize(250,18);
defAnnWindow.NameText:SetFont(Turbine.UI.Lotro.Font.Verdana16);
defAnnWindow.NameText:SetMultiline(false);

defAnnWindow.DescriptionCaption=Turbine.UI.Label();
defAnnWindow.DescriptionCaption:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.DescriptionCaption:SetPosition(0,defAnnWindow.NameCaption:GetTop()+25);
defAnnWindow.DescriptionCaption:SetSize(90,18);
defAnnWindow.DescriptionCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
defAnnWindow.DescriptionCaption:SetForeColor(Settings.fontColor);
defAnnWindow.DescriptionCaption:SetText("Descrip.:");
defAnnWindow.DescriptionCaption:SetMouseVisible(false);
defAnnWindow.DescriptionText=Turbine.UI.Lotro.TextBox();
defAnnWindow.DescriptionText:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.DescriptionText:SetPosition(90,defAnnWindow.DescriptionCaption:GetTop());
defAnnWindow.DescriptionText:SetSize(440,72);
defAnnWindow.DescriptionText:SetFont(Turbine.UI.Lotro.Font.Verdana16);
defAnnWindow.DescriptionText:SetMultiline(true);

defAnnWindow.NSCoordCaption=Turbine.UI.Label();
defAnnWindow.NSCoordCaption:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.NSCoordCaption:SetPosition(0,defAnnWindow.DescriptionCaption:GetTop()+25+54);
defAnnWindow.NSCoordCaption:SetSize(90,18);
defAnnWindow.NSCoordCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
defAnnWindow.NSCoordCaption:SetForeColor(Settings.fontColor);
defAnnWindow.NSCoordCaption:SetText("N/S:");
defAnnWindow.NSCoordCaption:SetMouseVisible(false);
defAnnWindow.NSCoordText=Turbine.UI.Lotro.TextBox();
defAnnWindow.NSCoordText:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.NSCoordText:SetPosition(90,defAnnWindow.NSCoordCaption:GetTop());
defAnnWindow.NSCoordText:SetSize(45,18);
defAnnWindow.NSCoordText:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);

defAnnWindow.NSButtons=RadioButtonGroup();
defAnnWindow.NSButtons:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.NSButtons:SetSize(90,20);
defAnnWindow.NSButtons:SetPosition(140,defAnnWindow.NSCoordCaption:GetTop());
defAnnWindow.NSButtons.UnselectedIcon=resourcePath.."RB_unselected.tga";
defAnnWindow.NSButtons.SelectedIcon=resourcePath.."RB_selected.tga";
defAnnWindow.NSButtons.IconWidth=16;
defAnnWindow.NSButtons.IconHeight=16;
defAnnWindow.NSButtons:SetBorderColor(Settings.backColor);
defAnnWindow.NSButtons:SetBackColor(Settings.backColor);
defAnnWindow.NSButtons:SetTextColor(Settings.fontColor);
defAnnWindow.NSButtons:AddChoice("N");
defAnnWindow.NSButtons:AddChoice("S");
defAnnWindow.NSButtons:SetRows(1);
defAnnWindow.NSButtons:SetSelectedChoice(2);
defAnnWindow.NSButtons.SelectionChanged=function()
end

-- quickslot to execute the command "/loc"
defAnnWindow.refineLocContainer=Turbine.UI.Control();
defAnnWindow.refineLocContainer:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.refineLocContainer:SetSize(32,32);
defAnnWindow.refineLocContainer:SetPosition(defAnnWindow.NSButtons:GetLeft()+defAnnWindow.NSButtons:GetWidth()+5,defAnnWindow.NSButtons:GetTop());
defAnnWindow.refineLoc=Turbine.UI.Lotro.Quickslot();
defAnnWindow.refineLoc:SetParent(defAnnWindow.refineLocContainer);
defAnnWindow.refineLoc:SetSize(66,66);
defAnnWindow.refineLoc:SetPosition(-34,-34);
defAnnWindow.refineLoc:SetAllowDrop(false);
defAnnWindow.refineLoc:SetShortcut(Turbine.UI.Lotro.Shortcut( Turbine.UI.Lotro.ShortcutType.Alias, "/loc"))
defAnnWindow.refineLoc:SetVisible(true);
defAnnWindow.refineLocIcon=Turbine.UI.Control();
defAnnWindow.refineLocIcon:SetParent(defAnnWindow.refineLocContainer);
defAnnWindow.refineLocIcon:SetPosition(0,0);
defAnnWindow.refineLocIcon:SetBlendMode(Turbine.UI.BlendMode.Overlay);
defAnnWindow.refineLocIcon:SetBackground(resourcePath.."reticle.tga");
defAnnWindow.refineLocIcon:SetSize(32,32);
defAnnWindow.refineLocIcon:SetMouseVisible(false);
defAnnWindow.refineLocIcon:SetVisible(true);

defAnnWindow.refineLoc.MouseUp=function(sender,args)
	defAnnWindow.refineLoc:SetShortcut(Turbine.UI.Lotro.Shortcut( Turbine.UI.Lotro.ShortcutType.Alias, "/loc"))
	defAnnWindow.refineLoc:SetVisible(true);
end

defAnnWindow.EWCoordCaption=Turbine.UI.Label();
defAnnWindow.EWCoordCaption:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.EWCoordCaption:SetPosition(0,defAnnWindow.NSCoordCaption:GetTop()+25);
defAnnWindow.EWCoordCaption:SetSize(90,18);
defAnnWindow.EWCoordCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
defAnnWindow.EWCoordCaption:SetForeColor(Settings.fontColor);
defAnnWindow.EWCoordCaption:SetText("E/W:");
defAnnWindow.EWCoordCaption:SetMouseVisible(false);
defAnnWindow.EWCoordText=Turbine.UI.Lotro.TextBox();
defAnnWindow.EWCoordText:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.EWCoordText:SetPosition(90,defAnnWindow.EWCoordCaption:GetTop());
defAnnWindow.EWCoordText:SetSize(45,18);
defAnnWindow.EWCoordText:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);

defAnnWindow.EWButtons=RadioButtonGroup();
defAnnWindow.EWButtons:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.EWButtons:SetSize(90,20);
defAnnWindow.EWButtons:SetPosition(140,defAnnWindow.EWCoordCaption:GetTop());
defAnnWindow.EWButtons.UnselectedIcon=resourcePath.."RB_unselected.tga";
defAnnWindow.EWButtons.SelectedIcon=resourcePath.."RB_selected.tga";
defAnnWindow.EWButtons.IconWidth=16;
defAnnWindow.EWButtons.IconHeight=16;
defAnnWindow.EWButtons:SetBorderColor(Settings.backColor);
defAnnWindow.EWButtons:SetBackColor(Settings.backColor);
defAnnWindow.EWButtons:SetTextColor(Settings.fontColor);
defAnnWindow.EWButtons:AddChoice("E");
defAnnWindow.EWButtons:AddChoice("W");
defAnnWindow.EWButtons:SetRows(1);
defAnnWindow.EWButtons:SetSelectedChoice(2);
defAnnWindow.EWButtons.SelectionChanged=function()
end

defAnnWindow.AllegianceCaption=Turbine.UI.Label();
defAnnWindow.AllegianceCaption:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.AllegianceCaption:SetPosition(0,defAnnWindow.EWCoordCaption:GetTop()+25);
defAnnWindow.AllegianceCaption:SetSize(90,18);
defAnnWindow.AllegianceCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
defAnnWindow.AllegianceCaption:SetForeColor(Settings.fontColor);
defAnnWindow.AllegianceCaption:SetText("Ally:");
defAnnWindow.AllegianceCaption:SetMouseVisible(false);

defAnnWindow.AllegianceButtons=RadioButtonGroup();
defAnnWindow.AllegianceButtons:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.AllegianceButtons:SetSize(440,20);
defAnnWindow.AllegianceButtons:SetPosition(90,defAnnWindow.AllegianceCaption:GetTop());
defAnnWindow.AllegianceButtons.UnselectedIcon=resourcePath.."RB_unselected.tga";
defAnnWindow.AllegianceButtons.SelectedIcon=resourcePath.."RB_selected.tga";
defAnnWindow.AllegianceButtons.IconWidth=16;
defAnnWindow.AllegianceButtons.IconHeight=16;
defAnnWindow.AllegianceButtons:SetBorderColor(Settings.backColor);
defAnnWindow.AllegianceButtons:SetBackColor(Settings.backColor);
defAnnWindow.AllegianceButtons:SetTextColor(Settings.fontColor);
defAnnWindow.AllegianceButtons:AddChoice("None");
defAnnWindow.AllegianceButtons:AddChoice("Creep");
defAnnWindow.AllegianceButtons:AddChoice("Freep");
defAnnWindow.AllegianceButtons:AddChoice("Delving");
defAnnWindow.AllegianceButtons:SetRows(1);
defAnnWindow.AllegianceButtons:SetSelectedChoice(3);
defAnnWindow.AllegianceButtons.SelectionChanged=function()
end

defAnnWindow.DataCaption=Turbine.UI.Label();
defAnnWindow.DataCaption:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.DataCaption:SetPosition(0,defAnnWindow.AllegianceCaption:GetTop()+25);
defAnnWindow.DataCaption:SetSize(90,18);
defAnnWindow.DataCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
defAnnWindow.DataCaption:SetForeColor(Settings.fontColor);
defAnnWindow.DataCaption:SetText("Data:");
defAnnWindow.DataCaption:SetMouseVisible(false);
defAnnWindow.DataText=Turbine.UI.Lotro.TextBox();
defAnnWindow.DataText:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.DataText:SetPosition(90,defAnnWindow.DataCaption:GetTop());
defAnnWindow.DataText:SetSize(250,18);
defAnnWindow.DataText:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
defAnnWindow.DataText:SetMultiline(false);
defAnnWindow.DataText:SetText("0");

defAnnWindow.NPCTypeCaption=Turbine.UI.Label();
defAnnWindow.NPCTypeCaption:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.NPCTypeCaption:SetPosition(0,defAnnWindow.DataCaption:GetTop()+25);
defAnnWindow.NPCTypeCaption:SetSize(90,18);
defAnnWindow.NPCTypeCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
defAnnWindow.NPCTypeCaption:SetForeColor(Settings.fontColor);
defAnnWindow.NPCTypeCaption:SetText("NPC Type:");
defAnnWindow.NPCTypeCaption:SetMouseVisible(false);

defAnnWindow.NPCTypeButtons=RadioButtonGroup();
defAnnWindow.NPCTypeButtons:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.NPCTypeButtons:SetSize(440,60);
defAnnWindow.NPCTypeButtons:SetPosition(90,defAnnWindow.NPCTypeCaption:GetTop());
defAnnWindow.NPCTypeButtons.UnselectedIcon=resourcePath.."RB_unselected.tga";
defAnnWindow.NPCTypeButtons.SelectedIcon=resourcePath.."RB_selected.tga";
defAnnWindow.NPCTypeButtons.IconWidth=16;
defAnnWindow.NPCTypeButtons.IconHeight=16;
defAnnWindow.NPCTypeButtons:SetBorderColor(Settings.backColor);
defAnnWindow.NPCTypeButtons:SetBackColor(Settings.backColor);
defAnnWindow.NPCTypeButtons:SetTextColor(Settings.fontColor);
defAnnWindow.NPCTypeButtons:AddChoice("None");
defAnnWindow.NPCTypeButtons:AddChoice("Bard/Corrupter");
defAnnWindow.NPCTypeButtons:AddChoice("Trainer");
defAnnWindow.NPCTypeButtons:AddChoice("Barter");
defAnnWindow.NPCTypeButtons:AddChoice("Merchant");
defAnnWindow.NPCTypeButtons:AddChoice("Stablemaster");
defAnnWindow.NPCTypeButtons:AddChoice("Captain General");
defAnnWindow.NPCTypeButtons:AddChoice("Named Mob");
defAnnWindow.NPCTypeButtons:SetRows(3);
defAnnWindow.NPCTypeButtons:SetSelectedChoice(1);
defAnnWindow.NPCTypeButtons.SelectionChanged=function()
end

defAnnWindow.QuestTypeCaption=Turbine.UI.Label();
defAnnWindow.QuestTypeCaption:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.QuestTypeCaption:SetPosition(0,defAnnWindow.NPCTypeCaption:GetTop()+65);
defAnnWindow.QuestTypeCaption:SetSize(90,18);
defAnnWindow.QuestTypeCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
defAnnWindow.QuestTypeCaption:SetForeColor(Settings.fontColor);
defAnnWindow.QuestTypeCaption:SetText("Quest Type:");
defAnnWindow.QuestTypeCaption:SetMouseVisible(false);

defAnnWindow.QuestTypeButtons=RadioButtonGroup();
defAnnWindow.QuestTypeButtons:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.QuestTypeButtons:SetSize(440,60);
defAnnWindow.QuestTypeButtons:SetPosition(90,defAnnWindow.QuestTypeCaption:GetTop());
defAnnWindow.QuestTypeButtons.UnselectedIcon=resourcePath.."RB_unselected.tga";
defAnnWindow.QuestTypeButtons.SelectedIcon=resourcePath.."RB_selected.tga";
defAnnWindow.QuestTypeButtons.IconWidth=16;
defAnnWindow.QuestTypeButtons.IconHeight=16;
defAnnWindow.QuestTypeButtons:SetBorderColor(Settings.backColor);
defAnnWindow.QuestTypeButtons:SetBackColor(Settings.backColor);
defAnnWindow.QuestTypeButtons:SetTextColor(Settings.fontColor);
defAnnWindow.QuestTypeButtons:AddChoice("None");
defAnnWindow.QuestTypeButtons:AddChoice("Creep");
defAnnWindow.QuestTypeButtons:AddChoice("Creep Grams");
defAnnWindow.QuestTypeButtons:AddChoice("Creep Lugz");
defAnnWindow.QuestTypeButtons:AddChoice("Creep Isen");
defAnnWindow.QuestTypeButtons:AddChoice("Creep TA");
defAnnWindow.QuestTypeButtons:AddChoice("Creep TR");
defAnnWindow.QuestTypeButtons:AddChoice("Creep LC");
defAnnWindow.QuestTypeButtons:AddChoice("Freep");
defAnnWindow.QuestTypeButtons:SetRows(3);
defAnnWindow.QuestTypeButtons:SetSelectedChoice(1);
defAnnWindow.QuestTypeButtons.SelectionChanged=function()
end

defAnnWindow.DropTypeCaption=Turbine.UI.Label();
defAnnWindow.DropTypeCaption:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.DropTypeCaption:SetPosition(0,defAnnWindow.QuestTypeCaption:GetTop()+65);
defAnnWindow.DropTypeCaption:SetSize(90,18);
defAnnWindow.DropTypeCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
defAnnWindow.DropTypeCaption:SetForeColor(Settings.fontColor);
defAnnWindow.DropTypeCaption:SetText("Drop Type:");
defAnnWindow.DropTypeCaption:SetMouseVisible(false);

defAnnWindow.DropTypeButtons=RadioButtonGroup();
defAnnWindow.DropTypeButtons:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.DropTypeButtons:SetSize(440,60);
defAnnWindow.DropTypeButtons:SetPosition(90,defAnnWindow.DropTypeCaption:GetTop());
defAnnWindow.DropTypeButtons.UnselectedIcon=resourcePath.."RB_unselected.tga";
defAnnWindow.DropTypeButtons.SelectedIcon=resourcePath.."RB_selected.tga";
defAnnWindow.DropTypeButtons.IconWidth=16;
defAnnWindow.DropTypeButtons.IconHeight=16;
defAnnWindow.DropTypeButtons:SetBorderColor(Settings.backColor);
defAnnWindow.DropTypeButtons:SetBackColor(Settings.backColor);
defAnnWindow.DropTypeButtons:SetTextColor(Settings.fontColor);
defAnnWindow.DropTypeButtons:AddChoice("None");
defAnnWindow.DropTypeButtons:AddChoice("Ruby Shard");
defAnnWindow.DropTypeButtons:AddChoice("Saphire Shard");
defAnnWindow.DropTypeButtons:AddChoice("Adamant Shard");
defAnnWindow.DropTypeButtons:AddChoice("Beryl Shard");
defAnnWindow.DropTypeButtons:AddChoice("Mithril Flake");
defAnnWindow.DropTypeButtons:AddChoice("Symbol of Celebrimbor");
defAnnWindow.DropTypeButtons:AddChoice("First Age thingy");
defAnnWindow.DropTypeButtons:AddChoice("Spare");
defAnnWindow.DropTypeButtons:SetRows(3);
defAnnWindow.DropTypeButtons:SetSelectedChoice(1);
defAnnWindow.DropTypeButtons.SelectionChanged=function()
end

-- quickslot to execute the command "/moormap target:;loc:;target"
local lang=Turbine.Engine:GetLanguage()
annotTargetStr="/MoorMap target ;loc:;target"
if lang==Turbine.Language.French then
	annotTargetStr="/MoorMap target ;loc:;cible"
elseif lang==Turbine.Language.German then
	annotTargetStr="/MoorMap target ;pos:;ziel"
end

defAnnWindow.getTargetInfoContainer=Turbine.UI.Control();
defAnnWindow.getTargetInfoContainer:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.getTargetInfoContainer:SetSize(32,32);
defAnnWindow.getTargetInfoContainer:SetPosition(0,defAnnWindow.DropTypeCaption:GetTop()+25);
defAnnWindow.getTargetInfo=Turbine.UI.Lotro.Quickslot();
defAnnWindow.getTargetInfo:SetParent(defAnnWindow.getTargetInfoContainer);
defAnnWindow.getTargetInfo:SetSize(66,66);
defAnnWindow.getTargetInfo:SetPosition(-34,-34);
defAnnWindow.getTargetInfo:SetAllowDrop(false);
defAnnWindow.getTargetInfo:SetShortcut(Turbine.UI.Lotro.Shortcut( Turbine.UI.Lotro.ShortcutType.Alias, annotTargetStr))
defAnnWindow.getTargetInfo:SetVisible(true);
defAnnWindow.getTargetInfoIcon=Turbine.UI.Control();
defAnnWindow.getTargetInfoIcon:SetParent(defAnnWindow.getTargetInfoContainer);
defAnnWindow.getTargetInfoIcon:SetPosition(0,0);
defAnnWindow.getTargetInfoIcon:SetSize(32,32);
defAnnWindow.getTargetInfoIcon:SetBackground(0x41000000);
defAnnWindow.getTargetInfoIcon:SetBlendMode(Turbine.UI.BlendMode.Overlay);
defAnnWindow.getTargetInfoIcon:SetMouseVisible(false);
defAnnWindow.getTargetInfoIcon:SetVisible(true);

defAnnWindow.getTargetInfo.MouseUp=function(sender,args)
	defAnnWindow.getTargetInfo:SetShortcut(Turbine.UI.Lotro.Shortcut( Turbine.UI.Lotro.ShortcutType.Alias, annotTargetStr))
	defAnnWindow.getTargetInfo:SetVisible(true);
end

defAnnWindow.writeEntry=Turbine.UI.Lotro.Button();
defAnnWindow.writeEntry:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.writeEntry:SetSize(32,32);
defAnnWindow.writeEntry:SetPosition(40,defAnnWindow.DropTypeCaption:GetTop()+25);
defAnnWindow.writeEntry:SetText("ADD");
defAnnWindow.writeEntry.Click=function()
	local stringIndex=tonumber(defAnnWindow.StringIndexText:GetText());
	if stringIndex==nil or stringIndex==0 then
		stringIndex=1;
	end
	local NSCoord=tonumber(defAnnWindow.NSCoordText:GetText());
	local EWCoord=tonumber(defAnnWindow.EWCoordText:GetText());
	if NSCoord==nil then NSCoord=0 end
	if EWCoord==nil then EWCoord=0 end
	if defAnnWindow.NSButtons:GetSelectedChoice()==2 then NSCoord=0-NSCoord end
	if defAnnWindow.EWButtons:GetSelectedChoice()==2 then EWCoord=0-EWCoord end

	defAnnWindow.AnnotationText:SetText(defAnnWindow.AnnotationText:GetText()..string.char(9)..string.UTFEncode("table.insert(tmpAnnotations,{"..tostring(defAnnWindow.MapSelect:GetValue())..","..tostring(NSCoord)..","..tostring(EWCoord)..", "..tostring(defAnnWindow.TypeList:GetValue())..", "..tostring(defAnnWindow.AllegianceButtons:GetSelectedChoice())..", "..tostring(stringIndex)..", \"\", "..defAnnWindow.DataText:GetText()..","..tostring(defAnnWindow.NPCTypeButtons:GetSelectedChoice()-1)..","..tostring(defAnnWindow.QuestTypeButtons:GetSelectedChoice()-1)..","..tostring(defAnnWindow.DropTypeButtons:GetSelectedChoice()-1).."});").."\r\n");
	defAnnWindow.ResourceText:SetText(defAnnWindow.ResourceText:GetText()..string.char(9)..string.UTFEncode("tmpMapString[1]["..tostring(stringIndex).."]=\""..defAnnWindow.NameText:GetText()..": "..defAnnWindow.DescriptionText:GetText().."\";").."\r\n");
	defAnnWindow.StringIndexText:SetText(tostring(stringIndex+1));
end
defAnnWindow.AnnotationTab=Turbine.UI.Control();
defAnnWindow.AnnotationTab:SetParent(defAnnWindow);
defAnnWindow.AnnotationTab:SetPosition(10,40);
defAnnWindow.AnnotationTab:SetSize(defAnnWindow:GetWidth()-20,defAnnWindow:GetHeight()-80);
defAnnWindow.AnnotationTab:SetBackColor(Turbine.UI.Color(0,0,0));
defAnnWindow.AnnotationTab:SetVisible(false);
defAnnWindow.AnnotationText=Turbine.UI.Lotro.TextBox();
defAnnWindow.AnnotationText:SetParent(defAnnWindow.AnnotationTab);
defAnnWindow.AnnotationText:SetFont(Turbine.UI.Lotro.Font.Verdana10) -- or Arial12
defAnnWindow.AnnotationText:SetMultiline(true);
defAnnWindow.AnnotationText:SetPosition(0,0);
defAnnWindow.AnnotationText:SetSize(defAnnWindow.AnnotationTab:GetWidth()-10,defAnnWindow.AnnotationTab:GetHeight());
defAnnWindow.AnnotationText:SetText("");

defAnnWindow.ResourceTab=Turbine.UI.Control();
defAnnWindow.ResourceTab:SetParent(defAnnWindow);
defAnnWindow.ResourceTab:SetPosition(10,40);
defAnnWindow.ResourceTab:SetSize(defAnnWindow:GetWidth()-20,defAnnWindow:GetHeight()-80);
defAnnWindow.ResourceTab:SetBackColor(Turbine.UI.Color(0,0,0));
defAnnWindow.ResourceTab:SetVisible(false);
defAnnWindow.ResourceText=Turbine.UI.Lotro.TextBox();
defAnnWindow.ResourceText:SetParent(defAnnWindow.ResourceTab);
defAnnWindow.ResourceText:SetFont(Turbine.UI.Lotro.Font.Verdana10) -- or Arial12
defAnnWindow.ResourceText:SetMultiline(true);
defAnnWindow.ResourceText:SetPosition(0,0);
defAnnWindow.ResourceText:SetSize(defAnnWindow.ResourceTab:GetWidth()-10,defAnnWindow.ResourceTab:GetHeight());
defAnnWindow.ResourceText:SetText("");

defAnnWindow.Recover=Turbine.UI.Lotro.Button();
defAnnWindow.Recover:SetParent(defAnnWindow.SettingsTab);
defAnnWindow.Recover:SetPosition(15,defAnnWindow.getTargetInfoContainer:GetTop()+42);
defAnnWindow.Recover:SetSize(100,20);
defAnnWindow.Recover:SetText("Recover");
defAnnWindow.Recover.Click=function()
	local tmpResult=PatchDataLoad(Turbine.DataScope.Account,"MoorMapAnnotText",setAnnotText)
	tmpResult=PatchDataLoad(Turbine.DataScope.Account,"MoorMapResourceText",setResourceText)
	--defAnnWindow.AnnotationText:SetText(convBack(defAnnWindow.AnnotationText:GetText()));
	--defAnnWindow.ResourceText:SetText(convBack(defAnnWindow.ResourceText:GetText()));
end

defAnnWindow.ShowSettings=Turbine.UI.Lotro.Button();
defAnnWindow.ShowSettings:SetParent(defAnnWindow);
defAnnWindow.ShowSettings:SetPosition(25,defAnnWindow:GetHeight()-35);
defAnnWindow.ShowSettings:SetSize(100,20);
defAnnWindow.ShowSettings:SetText("Settings");
defAnnWindow.ShowSettings.Click=function()
	defAnnWindow.SettingsTab:SetVisible(true);
	defAnnWindow.AnnotationTab:SetVisible(false);
	defAnnWindow.ResourceTab:SetVisible(false);
end

defAnnWindow.ShowAnnotations=Turbine.UI.Lotro.Button();
defAnnWindow.ShowAnnotations:SetParent(defAnnWindow);
defAnnWindow.ShowAnnotations:SetPosition((defAnnWindow:GetWidth()-80)/2,defAnnWindow:GetHeight()-35);
defAnnWindow.ShowAnnotations:SetSize(100,20);
defAnnWindow.ShowAnnotations:SetText("Annotations");
defAnnWindow.ShowAnnotations.Click=function()
	defAnnWindow.SettingsTab:SetVisible(false);
	defAnnWindow.AnnotationTab:SetVisible(true);
	defAnnWindow.ResourceTab:SetVisible(false);
end

defAnnWindow.ShowResources=Turbine.UI.Lotro.Button();
defAnnWindow.ShowResources:SetParent(defAnnWindow);
defAnnWindow.ShowResources:SetPosition(defAnnWindow:GetWidth()-125,defAnnWindow:GetHeight()-35);
defAnnWindow.ShowResources:SetSize(100,20);
defAnnWindow.ShowResources:SetText("Resources");
defAnnWindow.ShowResources.Click=function()
	defAnnWindow.SettingsTab:SetVisible(false);
	defAnnWindow.AnnotationTab:SetVisible(false);
	defAnnWindow.ResourceTab:SetVisible(true);
end

defAnnWindow.SetTargetInfo=function(Sender,NSCoord,EWCoord,iconType,tier,target)
	if not defAnnWindow.TypeLock.Locked and iconType~=nil and iconType~=0 then
		local tmpIndex;
		for tmpIndex=1,defAnnWindow.TypeList.ListData:GetItemCount() do
			if defAnnWindow.TypeList.ListData:GetItem(tmpIndex).DataValue==iconType then
				defAnnWindow.TypeList:SetSelectedIndex(tmpIndex);
				break;
			end
		end
	end
	if NSCoord~=nil then
		if NSCoord<0 then
			defAnnWindow.NSCoordText:SetText(tostring(0-NSCoord));
			defAnnWindow.NSButtons:SetSelectedChoice(2);
		else
			defAnnWindow.NSCoordText:SetText(tostring(NSCoord));
			defAnnWindow.NSButtons:SetSelectedChoice(1);
		end
	end
	if EWCoord~=nil then
		if EWCoord<0 then
			defAnnWindow.EWCoordText:SetText(tostring(0-EWCoord));
			defAnnWindow.EWButtons:SetSelectedChoice(2);
		else
			defAnnWindow.EWCoordText:SetText(tostring(EWCoord));
			defAnnWindow.EWButtons:SetSelectedChoice(1);
		end
	end
	if tier==nil or tier=="" then
		defAnnWindow.DataText:SetText("");
	else
		defAnnWindow.DataText:SetText(tostring(tier));
	end
	defAnnWindow.NameText:SetText(target);
	defAnnWindow.DescriptionText:SetText(target);
end
defAnnWindow:SetZOrder(1);
-- reload prior annotations in case map got unloaded with unsaved annotations
function setAnnotText(tmpAnnotText)
	if tmpAnnotText~=nil and tmpAnnotText~="" then
		defAnnWindow.AnnotationText:SetText(convBack(tmpAnnotText))
	end
end
function setResourceText(tmpResourceText)
	if tmpResourceText~=nil and tmpResourceText~="" then
		defAnnWindow.ResourceText:SetText(convBack(tmpResourceText))
	end
end
